@@ -88,14 +88,14 @@ bool processArgs(QCommandLineParser* parser, DiscoverMainWindow* mainWindow)
 int main(int argc, char** argv)
 {
     QApplication app(argc, argv);
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("muondiscover")));
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("plasmadiscover")));
     app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 #ifdef WITH_KCRASH_INIT
     KCrash::initialize();
 #endif
     KLocalizedString::setApplicationDomain("plasma-discover");
-    KAboutData about(QStringLiteral("muondiscover"), i18n("Discover"), version, i18n("An application explorer"),
+    KAboutData about(QStringLiteral("discover"), i18n("Discover"), version, i18n("An application explorer"),
                      KAboutLicense::GPL, i18n("© 2010-2016 Plasma Development Team"));
     about.addAuthor(i18n("Aleix Pol Gonzalez"), QString(), QStringLiteral("aleixpol@blue-systems.com"));
     about.addAuthor(i18n("Jonathan Thomas"), QString(), QStringLiteral("echidnaman@kubuntu.org"));
@@ -118,6 +118,9 @@ int main(int argc, char** argv)
         mainWindow = new DiscoverMainWindow(decodeCompactMode(parser->value(QStringLiteral("compact"))));
         QObject::connect(&app, &QApplication::aboutToQuit, mainWindow, &DiscoverMainWindow::deleteLater);
         QObject::connect(service, &KDBusService::activateRequested, mainWindow, [mainWindow](const QStringList &arguments, const QString &/*workingDirectory*/){
+            mainWindow->rootObject()->raise();
+            if (arguments.isEmpty())
+                return;
             QScopedPointer<QCommandLineParser> parser(createParser());
             parser->process(arguments);
             processArgs(parser.data(), mainWindow);
