@@ -62,7 +62,7 @@ public:
         /// Transaction is done
         DoneStatus
     };
-    Q_ENUMS(Status)
+    Q_ENUM(Status)
 
     enum Role {
         ///The transaction is going to install a resource
@@ -72,12 +72,10 @@ public:
         ///The transaction is going to change the addons of a resource
         ChangeAddonsRole
     };
-    Q_ENUMS(Role)
+    Q_ENUM(Role)
 
     Transaction(QObject *parent, AbstractResource *resource,
-                 Transaction::Role role);
-    Transaction(QObject *parent, AbstractResource *resource,
-                 Transaction::Role role, const AddonList &addons);
+                 Transaction::Role role, const AddonList &addons = {});
 
     /**
      * @returns the AbstractResource which this transaction works with
@@ -122,13 +120,18 @@ public:
     /**
      * Cancels the transaction
      */
-    void cancel();
+    virtual void cancel() = 0;
+
+    /**
+     * @returns if the transaction is either downloading or committing
+     */
+    bool isActive() const;
 
 private:
-    AbstractResource *m_resource;
-    Role m_role;
+    AbstractResource * const m_resource;
+    const Role m_role;
     Status m_status;
-    AddonList m_addons;
+    const AddonList m_addons;
     bool m_isCancellable;
     int m_progress;
 
