@@ -21,8 +21,11 @@
 #include "AppPackageKitResource.h"
 #include <AppstreamQt/screenshot.h>
 #include <AppstreamQt/image.h>
+// #include <AppstreamQt/release.h>
 #include <KLocalizedString>
 #include <KToolInvocation>
+#include <QIcon>
+#include <QProcess>
 #include <QDebug>
 
 AppPackageKitResource::AppPackageKitResource(const Appstream::Component& data, PackageKitBackend* parent)
@@ -46,17 +49,20 @@ QString AppPackageKitResource::longDescription()
     return PackageKitResource::longDescription();
 }
 
-QString AppPackageKitResource::icon() const
+QVariant AppPackageKitResource::icon() const
 {
-    const QString anIcon = m_appdata.icon();
-    if (!anIcon.isEmpty())
-        return anIcon;
+    QIcon ret;
 
-    const QUrl iconUrl = m_appdata.iconUrl(QSize());
-    if (iconUrl.isLocalFile())
-        return iconUrl.toLocalFile();
-
-    return QStringLiteral("applications-other");
+    const auto icons = m_appdata.iconUrls();
+    if (icons.isEmpty())
+        return m_appdata.name();
+    else {
+        for (auto it = icons.constBegin(), itEnd = icons.constEnd(); it!=itEnd; ++it) {
+            if (it->isLocalFile())
+                ret.addFile(it->toLocalFile(), it.key());
+        }
+    }
+    return ret;
 }
 
 QString AppPackageKitResource::license()
@@ -72,7 +78,9 @@ QStringList AppPackageKitResource::mimetypes() const
 
 QStringList AppPackageKitResource::categories()
 {
-    return m_appdata.categories();
+    auto cats = m_appdata.categories();
+    cats.append(QStringLiteral("Application"));
+    return cats;
 }
 
 QString AppPackageKitResource::comment()
@@ -109,7 +117,7 @@ void AppPackageKitResource::invokeApplication() const
 {
     QStringList exes = executables();
     if(!exes.isEmpty())
-        KToolInvocation::startServiceByDesktopPath(exes.first());
+        QProcess::startDetached(exes.first());
 }
 
 static QUrl imageOfKind(const QList<Appstream::Image>& images, Appstream::Image::Kind kind)
@@ -198,3 +206,15 @@ QStringList AppPackageKitResource::extends() const
 {
     return m_appdata.extends();
 }
+
+void AppPackageKitResource::fetchChangelog()
+{
+    PackageKitResource::fetchChangelog();
+    //TODO: uncomment when the API is publicly released
+//     QString changelog;
+//     for(const auto& rel: m_appdata.releases()) {
+//         changelog += QStringLiteral("<h3>") + rel.version() + QStringLiteral("</h3>");
+//         changelog += QStringLiteral("<p>") + rel.description() + QStringLiteral("</p>");
+//     }
+//     emit changelogFetched(changelog);
+}
