@@ -43,6 +43,8 @@
 #include <KLocalizedString>
 #include <QAction>
 
+#include "utils.h"
+
 MUON_BACKEND_PLUGIN(PackageKitBackend)
 
 PackageKitBackend::PackageKitBackend(QObject* parent)
@@ -155,6 +157,8 @@ void PackageKitBackend::fetchUpdates()
     connect(tUpdates, &PackageKit::Transaction::package, this, &PackageKitBackend::addPackageToUpdate);
     connect(tUpdates, &PackageKit::Transaction::errorCode, this, &PackageKitBackend::transactionError);
     m_updatesPackageId.clear();
+
+    m_updater->setProgressing(true);
 }
 
 
@@ -236,6 +240,22 @@ QSet<AbstractResource*> PackageKitBackend::resourcesByPackageName(const QString&
     return ret;
 }
 
+template <typename T>
+T PackageKitBackend::resourcesByPackageNames(const QStringList &pkgnames) const
+{
+    T ret;
+    ret.reserve(pkgnames.size());
+    for(const QString &name : pkgnames) {
+        const QStringList names = m_packages.packageToApp.value(name, QStringList(name));
+        foreach(const QString& name, names) {
+            AbstractResource* res = m_packages.packages.value(name);
+            if (res)
+                ret += res;
+        }
+    }
+    return ret;
+}
+
 void PackageKitBackend::refreshDatabase()
 {
     if (!m_refresher) {
@@ -264,20 +284,10 @@ AbstractResource* PackageKitBackend::resourceByPackageName(const QString& name)
 
 QList<AbstractResource*> PackageKitBackend::searchPackageName(const QString& searchText)
 {
-    QList<AbstractResource*> ret;
-    Q_FOREACH (AbstractResource* res, m_packages.packages) {
-        if (res->name().contains(searchText, Qt::CaseInsensitive)) {
-            ret += res;
-        } else {
-            foreach(const QString &mime, res->mimetypes()) {
-                if (mime.contains(searchText, Qt::CaseInsensitive)) {
-                    ret += res;
-                    break;
-                }
-            }
-        }
-    }
-    return ret;
+    const QList<Appstream::Component> components = m_appdata.findComponentsByString(searchText, {});
+    const QStringList ids = kTransform<QStringList>(components, [](const Appstream::Component& comp) { return comp.id(); });
+
+    return resourcesByPackageNames<QList<AbstractResource*>>(ids);
 }
 
 int PackageKitBackend::updatesCount() const
@@ -378,6 +388,8 @@ void PackageKitBackend::getUpdatesFinished(PackageKit::Transaction::Exit, uint)
         connect(transaction, &PackageKit::Transaction::finished, this, &PackageKitBackend::getUpdatesDetailsFinished);
     }
 
+    m_updater->setProgressing(false);
+
     includePackagesToAdd();
     emit updatesCountChanged();
 }
