@@ -86,7 +86,7 @@ QUrl PackageKitResource::homepage()
     return QUrl(m_details.url());
 }
 
-QString PackageKitResource::icon() const
+QVariant PackageKitResource::icon() const
 {
     return QStringLiteral("applications-other");
 }
@@ -94,7 +94,7 @@ QString PackageKitResource::icon() const
 QString PackageKitResource::license()
 {
     fetchDetails();
-    return m_details.license();
+    return m_details.license().isEmpty() ? i18n("Unknown") : m_details.license();
 }
 
 QList<PackageState> PackageKitResource::addonsInformation()
