@@ -106,10 +106,7 @@ class DISCOVERCOMMON_EXPORT AbstractBackendUpdater : public QObject
          * @returns the QDateTime when the last update happened
          */
         virtual QDateTime lastUpdate() const = 0;
-        /**
-         * @returns true when upgradeable packages are marked be upgraded
-         */
-        virtual bool isAllMarked() const = 0;
+
         /**
          * @returns whether the updater can currently be canceled or not
          * @see cancelableChanged
@@ -141,6 +138,8 @@ class DISCOVERCOMMON_EXPORT AbstractBackendUpdater : public QObject
          */
         virtual bool isMarked(AbstractResource* res) const = 0;
 
+        virtual void fetchChangelog() const;
+
     public Q_SLOTS:
         /**
          * If \isCancelable is true during the transaction, this method has
@@ -198,6 +197,11 @@ class DISCOVERCOMMON_EXPORT AbstractBackendUpdater : public QObject
          * @see downloadSpeed
          */
         void downloadSpeedChanged(quint64);
+
+        /**
+         * Provides the @p progress of a specific @p resource in a percentage.
+         */
+        void resourceProgressed(AbstractResource* resource, qreal progress);
 };
 
 #endif // ABSTRACTBACKENDUPDATER_H
