@@ -53,9 +53,11 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QAbstractListModel
             PackageNameRole,
             IsTechnicalRole,
             CategoryRole,
+            CategoryDisplayRole,
             SectionRole,
             MimeTypes,
-            SizeRole
+            SizeRole,
+            LongDescriptionRole
         };
         /** This constructor should be only used by unit tests.
          *  @p backendName defines what backend will be loaded when the backend is constructed.
